/*
Copyright (c) 2018-2020 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
export const shouldShowValue = (state, props) => {
  const {
    inputValue,
    isPseudoFocused,
    isFocused
  } = state;
  const {
    onSelectResetsInput
  } = props;
  if (!inputValue) return true;

  if (!onSelectResetsInput) {
    return !(!isFocused && isPseudoFocused || isFocused && !isPseudoFocused);
  }

  return false;
};
export const shouldShowPlaceholder = (state, props, isOpen) => {
  const {
    inputValue,
    isPseudoFocused,
    isFocused
  } = state;
  const {
    onSelectResetsInput
  } = props;
  return !inputValue || !onSelectResetsInput && !isOpen && !isPseudoFocused && !isFocused;
};

function groupedOptionsToArray(groupedOptions) {
  return Object.keys(groupedOptions).reduce((arr, optgroup) => {
    const optgroupOptions = groupedOptions[optgroup];
    return arr.concat(optgroupOptions.map(option => {
      return { ...option,
        __optgroup: optgroup
      };
    }));
  }, []);
}

export function normalizeOptions(options) {
  if (options) {
    if (Array.isArray(options)) {
      return options;
    } else {
      return groupedOptionsToArray(options);
    }
  }

  return [];
}
export const expandValue = (value, props) => {
  if (!props.options) return value;
  const normalizedOptions = normalizeOptions(props.options);

  for (let i = 0; i < normalizedOptions.length; i++) {
    if (String(normalizedOptions[i][props.valueKey]) === String(value[props.valueKey])) {
      return normalizedOptions[i];
    }
  }

  return value;
};